#ifndef AUDM_TWOLAME_PARAM_H
#define AUDM_TWOLAME_PARAM_H


typedef struct 
{
  ADM_mode        mode;
}TWOLAME_encoderParam;

#endif
